@@ -1022,8 +1022,10 @@ types: list[str] = [
     "AWS::S3Outposts::BucketPolicy",
     "AWS::S3Outposts::Endpoint",
     "AWS::S3Tables::Namespace",
+    "AWS::S3Tables::Table",
     "AWS::S3Tables::TableBucket",
     "AWS::S3Tables::TableBucketPolicy",
+    "AWS::S3Tables::TablePolicy",
     "AWS::SDB::Domain",
     "AWS::SES::ConfigurationSet",
     "AWS::SES::ConfigurationSetEventDestination",
@@ -1223,6 +1225,7 @@ types: list[str] = [
     "AWS::Wisdom::KnowledgeBase",
     "AWS::Wisdom::MessageTemplate",
     "AWS::Wisdom::MessageTemplateVersion",
+    "AWS::Wisdom::QuickResponse",
     "AWS::WorkSpaces::ConnectionAlias",
     "AWS::WorkSpaces::Workspace",
     "AWS::WorkSpaces::WorkspacesPool",
@@ -1248,7 +1251,6 @@ cached: list[str] = [
     "aws-acmpca-permission.json",
     "aws-amazonmq-broker.json",
     "aws-amazonmq-configuration.json",
-    "aws-amazonmq-configurationassociation.json",
     "aws-amplify-app.json",
     "aws-amplify-branch.json",
     "aws-amplify-domain.json",
@@ -1272,7 +1274,6 @@ cached: list[str] = [
     "aws-apigateway-model.json",
     "aws-apigateway-requestvalidator.json",
     "aws-apigateway-resource.json",
-    "aws-apigateway-restapi.json",
     "aws-apigateway-stage.json",
     "aws-apigateway-usageplan.json",
     "aws-apigateway-usageplankey.json",
@@ -1295,7 +1296,6 @@ cached: list[str] = [
     "aws-appconfig-configurationprofile.json",
     "aws-appconfig-deployment.json",
     "aws-appconfig-deploymentstrategy.json",
-    "aws-appconfig-environment.json",
     "aws-appconfig-extension.json",
     "aws-appconfig-extensionassociation.json",
     "aws-appconfig-hostedconfigurationversion.json",
@@ -1378,6 +1378,7 @@ cached: list[str] = [
     "aws-bedrock-flow.json",
     "aws-bedrock-flowalias.json",
     "aws-bedrock-flowversion.json",
+    "aws-bedrock-guardrail.json",
     "aws-bedrock-guardrailversion.json",
     "aws-bedrock-intelligentpromptrouter.json",
     "aws-bedrock-knowledgebase.json",
@@ -1583,14 +1584,13 @@ cached: list[str] = [
     "aws-dms-replicationinstance.json",
     "aws-dms-replicationsubnetgroup.json",
     "aws-dms-replicationtask.json",
+    "aws-docdb-dbcluster.json",
     "aws-docdb-dbclusterparametergroup.json",
     "aws-docdb-dbinstance.json",
     "aws-docdb-dbsubnetgroup.json",
     "aws-docdb-eventsubscription.json",
     "aws-docdbelastic-cluster.json",
     "aws-dsql-cluster.json",
-    "aws-dynamodb-globaltable.json",
-    "aws-dynamodb-table.json",
     "aws-ec2-capacityreservation.json",
     "aws-ec2-capacityreservationfleet.json",
     "aws-ec2-carriergateway.json",
@@ -1652,6 +1652,7 @@ cached: list[str] = [
     "aws-ec2-trafficmirrorfilter.json",
     "aws-ec2-trafficmirrorfilterrule.json",
     "aws-ec2-trafficmirrorsession.json",
+    "aws-ec2-trafficmirrortarget.json",
     "aws-ec2-transitgateway.json",
     "aws-ec2-transitgatewayattachment.json",
     "aws-ec2-transitgatewayconnect.json",
@@ -1693,7 +1694,6 @@ cached: list[str] = [
     "aws-ecr-repository.json",
     "aws-ecr-repositorycreationtemplate.json",
     "aws-ecs-capacityprovider.json",
-    "aws-ecs-cluster.json",
     "aws-ecs-clustercapacityproviderassociations.json",
     "aws-ecs-primarytaskset.json",
     "aws-ecs-service.json",
@@ -1724,7 +1724,6 @@ cached: list[str] = [
     "aws-elasticbeanstalk-configurationtemplate.json",
     "aws-elasticbeanstalk-environment.json",
     "aws-elasticloadbalancing-loadbalancer.json",
-    "aws-elasticloadbalancingv2-listener.json",
     "aws-elasticloadbalancingv2-listenercertificate.json",
     "aws-elasticloadbalancingv2-listenerrule.json",
     "aws-elasticloadbalancingv2-loadbalancer.json",
@@ -1744,7 +1743,6 @@ cached: list[str] = [
     "aws-emrserverless-application.json",
     "aws-entityresolution-idmappingworkflow.json",
     "aws-entityresolution-idnamespace.json",
-    "aws-entityresolution-matchingworkflow.json",
     "aws-entityresolution-policystatement.json",
     "aws-entityresolution-schemamapping.json",
     "aws-events-apidestination.json",
@@ -1857,6 +1855,7 @@ cached: list[str] = [
     "aws-imagebuilder-component.json",
     "aws-imagebuilder-containerrecipe.json",
     "aws-imagebuilder-distributionconfiguration.json",
+    "aws-imagebuilder-image.json",
     "aws-imagebuilder-imagepipeline.json",
     "aws-imagebuilder-imagerecipe.json",
     "aws-imagebuilder-infrastructureconfiguration.json",
@@ -1930,6 +1929,7 @@ cached: list[str] = [
     "aws-kafkaconnect-workerconfiguration.json",
     "aws-kinesis-resourcepolicy.json",
     "aws-kinesis-stream.json",
+    "aws-kinesis-streamconsumer.json",
     "aws-kinesisanalytics-application.json",
     "aws-kinesisanalytics-applicationoutput.json",
     "aws-kinesisanalytics-applicationreferencedatasource.json",
@@ -1937,7 +1937,6 @@ cached: list[str] = [
     "aws-kinesisanalyticsv2-applicationcloudwatchloggingoption.json",
     "aws-kinesisanalyticsv2-applicationoutput.json",
     "aws-kinesisanalyticsv2-applicationreferencedatasource.json",
-    "aws-kinesisfirehose-deliverystream.json",
     "aws-kinesisvideo-signalingchannel.json",
     "aws-kinesisvideo-stream.json",
     "aws-kms-alias.json",
@@ -1959,7 +1958,6 @@ cached: list[str] = [
     "aws-lambda-layerversionpermission.json",
     "aws-lambda-permission.json",
     "aws-lambda-url.json",
-    "aws-lambda-version.json",
     "aws-launchwizard-deployment.json",
     "aws-lex-bot.json",
     "aws-lex-botalias.json",
@@ -1978,7 +1976,6 @@ cached: list[str] = [
     "aws-lightsail-loadbalancer.json",
     "aws-lightsail-loadbalancertlscertificate.json",
     "aws-lightsail-staticip.json",
-    "aws-logs-accountpolicy.json",
     "aws-logs-delivery.json",
     "aws-logs-deliverydestination.json",
     "aws-logs-deliverysource.json",
@@ -2169,16 +2166,13 @@ cached: list[str] = [
     "aws-rds-globalcluster.json",
     "aws-rds-integration.json",
     "aws-rds-optiongroup.json",
-    "aws-redshift-cluster.json",
     "aws-redshift-clusterparametergroup.json",
     "aws-redshift-clustersecuritygroup.json",
     "aws-redshift-clustersecuritygroupingress.json",
     "aws-redshift-clustersubnetgroup.json",
-    "aws-redshift-endpointaccess.json",
     "aws-redshift-endpointauthorization.json",
     "aws-redshift-eventsubscription.json",
     "aws-redshift-integration.json",
-    "aws-redshift-scheduledaction.json",
     "aws-redshiftserverless-namespace.json",
     "aws-redshiftserverless-snapshot.json",
     "aws-redshiftserverless-workgroup.json",
@@ -2201,7 +2195,6 @@ cached: list[str] = [
     "aws-route53-cidrcollection.json",
     "aws-route53-dnssec.json",
     "aws-route53-healthcheck.json",
-    "aws-route53-hostedzone.json",
     "aws-route53-keysigningkey.json",
     "aws-route53-recordset.json",
     "aws-route53-recordsetgroup.json",
@@ -2222,9 +2215,7 @@ cached: list[str] = [
     "aws-s3-accesspoint.json",
     "aws-s3-bucket.json",
     "aws-s3-bucketpolicy.json",
-    "aws-s3-multiregionaccesspoint.json",
     "aws-s3-multiregionaccesspointpolicy.json",
-    "aws-s3-storagelens.json",
     "aws-s3-storagelensgroup.json",
     "aws-s3objectlambda-accesspoint.json",
     "aws-s3objectlambda-accesspointpolicy.json",
@@ -2233,8 +2224,10 @@ cached: list[str] = [
     "aws-s3outposts-bucketpolicy.json",
     "aws-s3outposts-endpoint.json",
     "aws-s3tables-namespace.json",
+    "aws-s3tables-table.json",
     "aws-s3tables-tablebucket.json",
     "aws-s3tables-tablebucketpolicy.json",
+    "aws-s3tables-tablepolicy.json",
     "aws-sagemaker-app.json",
     "aws-sagemaker-appimageconfig.json",
     "aws-sagemaker-coderepository.json",
@@ -2433,6 +2426,7 @@ cached: list[str] = [
     "aws-wisdom-knowledgebase.json",
     "aws-wisdom-messagetemplate.json",
     "aws-wisdom-messagetemplateversion.json",
+    "aws-wisdom-quickresponse.json",
     "aws-workspaces-connectionalias.json",
     "aws-workspaces-workspace.json",
     "aws-workspaces-workspacespool.json",
